# youtube-analyzer

![Versão](https://img.shields.io/badge/version-0.3.4-orange)
![Licença](https://img.shields.io/badge/license-MIT-orange)
[![Sponsor](https://img.shields.io/badge/💲Donate-yellow)](https://apoia.se/paulocesar-dev404)
[![Sponsor](https://img.shields.io/badge/Documentation-green)](https://github.com/PauloCesar-dev404/youtube_analyzer/wiki)


Obtenha detalhes de vídeos do youtube usando esta lib
---
- [x] Obter detalhes de um vídeo
- [x] obter legendas
- [x] Analizar playlists
- [x] Obter detalhes de uris de Vídeos
- [x] Download de Videos
- [x] Download de Audio
- [x] interface linha de comando `yt-downloader`
